require 'spec_helper'

describe ProxySeeker::Fetcher do
  let(:fetcher) { ProxySeeker::Fetcher.new }
  let(:valid_proxy) { ::ProxySeeker::Proxy.new('190.235.199.189', '3128')}
  let(:invalid_proxy1) { ::ProxySeeker::Proxy.new('AAAA', '3128') }
  let(:invalid_proxy2) { ::ProxySeeker::Proxy.new('190.235.199.189', 'BBB') }

  context "returned results" do
    before do
      allow_any_instance_of(::ProxySeeker::Fetcher).to receive(:scrapers).and_return([::ProxySeeker::Scrapers::ProxyListenScraper])
      allow_any_instance_of(::ProxySeeker::Scrapers::ProxyListenScraper).to receive(:fetch).and_return([valid_proxy, invalid_proxy1, invalid_proxy2])
    end

    it "return return results as enumerable proxy classes collection" do
      results = fetcher.execute

      expect(results).not_to be_empty
      expect(results.last).to be_a ::ProxySeeker::Proxy
    end

    it "clear not valid proxy instances" do
      results = fetcher.execute

      expect(results.size).to eq 1
      expect(results).not_to eq include(invalid_proxy1, invalid_proxy2)
    end
  end
end